export interface Phase {
    /** Phase information. */
    info?: PhaseInfo;
    /** Cards contained in the phase. */
    cardsList?: CardsList;
}
export interface PhaseInfo {
    /**
     * Phase ID.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /** Display name shown at the top of the phase. */
    name?: string | null;
}
/** a list of cards (a page) along with the total number */
export interface CardsList {
    /** Total number of cards in the phase. */
    total?: number;
    /**
     * List of cards in the phase.
     * Sorted according to the card display order, from top to bottom.
     */
    cards?: Card[];
}
export interface Card {
    /** Card details. */
    info?: CardInfo;
}
/** entity representing a card-info */
export interface CardInfo {
    /**
     * Card ID.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /** Display name shown at the top of the card. */
    name?: string | null;
    /** Card description. */
    description?: string | null;
    /** Details about the contact attached to the card. */
    primaryAttachment?: Attachment;
    /** Due date. */
    dueDate?: Date | null;
    /** Name of the app or service that created the contact. */
    source?: string | null;
    /**
     * Deprecated. Use `createdDate` instead.
     * @readonly
     * @deprecated
     */
    createdAt?: Date | null;
    /**
     * Deprecated. Use `updatedDate` instead.
     * @readonly
     * @deprecated
     */
    updatedAt?: Date | null;
    /**
     * ID of the phase that currently holds the card.
     * @format GUID
     * @readonly
     */
    phaseId?: string | null;
    /**
     * Date and time the card was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the card was updated.
     * @readonly
     */
    updatedDate?: Date | null;
}
export interface Attachment {
    /**
     * Attachment ID. For internal use.
     * @format GUID
     * @readonly
     */
    attachmentId?: string;
    /**
     * Deprecated. Use `contactId` instead.
     * @deprecated
     */
    value?: string;
    /**
     * Deprecated. For internal use.
     * @deprecated
     */
    attachmentType?: AttachmentTypeWithLiterals;
    /**
     * ID of the contact attached to the card.
     * @format GUID
     */
    contactId?: string;
}
/** describes the supported types of attachments (currently only supports Contact which is the default type) */
export declare enum AttachmentType {
    ContactType = "ContactType"
}
/** @enumType */
export type AttachmentTypeWithLiterals = AttachmentType | 'ContactType';
export interface QueryPhasesRequest {
    /** Query, sort, and paging options. */
    query?: Query;
}
export interface Query {
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * Example of operators: `$eq`, `$ne`, `$lt`, `$lte`, `$gt`, `$gte`, `$in`, `$hasSome`, `$hasAll`, `$startsWith`, `$contains`
     */
    filter?: any;
    /**
     * Sort object in the following format:
     * `[{"fieldName":"sortField1","order":"ASC"},{"fieldName":"sortField2","order":"DESC"}]`
     */
    sort?: Sorting[];
    /** Paging options to limit and skip the number of items. */
    paging?: Paging;
    /** Array of projected fields. A list of specific field names to return. If `fieldsets` are also specified, the union of `fieldsets` and `fields` is returned. */
    fields?: string[];
    /** Array of named, predefined sets of projected fields. A array of predefined named sets of fields to be returned. Specifying multiple `fieldsets` will return the union of fields from all sets. If `fields` are also specified, the union of `fieldsets` and `fields` is returned. */
    fieldsets?: string[];
}
export interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
export declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
export type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
export interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
export interface QueryPhasesResponse {
    /** List of phases that matched the query criteria. */
    phases?: Phase[];
    /** Metadata for the page of results. */
    pagination?: PaginationResponse;
}
export interface PaginationResponse {
    /** Number of items that were skipped in the current sort order. */
    offset?: number;
    /** Total number of items that matched the filter. */
    total?: number;
    /** Number of returned items. */
    count?: number;
}
export interface ListPhasesRequest {
    /**
     * ID of the workflow whose phases will be listed.
     * @format GUID
     */
    workflowId: string;
    /** Number of items to return. */
    limit?: number | null;
    /**
     * Number of items to skip in the current sort order.
     *
     * Defaults to `0`.
     */
    offset?: number | null;
    /**
     * Supported fields:
     * `id`, `name`
     *
     * List of fields to sort by.
     * Formatted as `field:direction`,
     * where field is the field name
     * and direction is `asc` (ascending) or `desc` (descending).
     *
     * Sorting is applied lexicographically, so `"abc"` comes after `"XYZ"`.
     */
    sort?: string[];
}
export interface ListPhasesResponse {
    /** List of phases. */
    phases?: Phase[];
    /** Metadata for the page of results. */
    pagination?: PaginationResponse;
}
export interface GetPhaseRequest {
    /**
     * ID of the phase to retrieve.
     * @format GUID
     */
    id: string;
}
export interface GetPhaseResponse {
    /** Requested phase. */
    phase?: Phase;
}
export interface UpdatePhaseRequest {
    /**
     * ID of the phase to update.
     * @format GUID
     */
    id: string;
    /** Phase details to update. */
    phase?: PhaseInfo;
}
export interface UpdatePhaseResponse {
}
export interface CreatePhaseRequest {
    /**
     * ID of the workflow to create the phase in.
     * @format GUID
     */
    workflowId: string;
    /** Phase details. */
    phase?: PhaseInfo;
    /**
     * Phase position, where the first phase is `0`.
     *
     * If a phase already occupies the specified position,
     * that phase and any subsequent phases
     * are shifted to the right by 1.
     *
     * Defaults to the last position,
     * which is displayed before the win phase.
     */
    position?: number | null;
}
export interface CreatePhaseResponse {
    /**
     * ID of the newly created phase.
     * @format GUID
     */
    id?: string | null;
}
export interface DeletePhaseRequest {
    /**
     * ID of the phase to delete.
     * @format GUID
     */
    id: string;
}
export interface DeletePhaseResponse {
}
export interface MovePhaseRequest {
    /**
     * ID of the workflow that contains the phase to move.
     * @format GUID
     */
    workflowId: string;
    /**
     * ID of the phase to move.
     * @format GUID
     */
    id: string;
    /**
     * New phase position, where the first phase is `0`.
     *
     * If a phase already occupies the specified position,
     * that phase and any subsequent phases
     * are shifted to the right by 1.
     */
    newPosition: number | null;
}
export interface MovePhaseResponse {
}
