import { NonNullablePaths } from '@wix/sdk-types';
export interface Phase {
    /** Phase information. */
    info?: PhaseInfo;
    /** Cards contained in the phase. */
    cardsList?: CardsList;
}
export interface PhaseInfo {
    /**
     * Phase ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /** Display name shown at the top of the phase. */
    name?: string | null;
}
/** a list of cards (a page) along with the total number */
export interface CardsList {
    /** Total number of cards in the phase. */
    total?: number;
    /**
     * List of cards in the phase.
     * Sorted according to the card display order, from top to bottom.
     */
    cards?: Card[];
}
export interface Card {
    /** Card details. */
    info?: CardInfo;
}
/** entity representing a card-info */
export interface CardInfo {
    /**
     * Card ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /** Display name shown at the top of the card. */
    name?: string | null;
    /** Card description. */
    description?: string | null;
    /** Details about the contact attached to the card. */
    primaryAttachment?: Attachment;
    /** Due date. */
    dueDate?: Date | null;
    /** Name of the app or service that created the contact. */
    source?: string | null;
    /**
     * @internal
     * @internal
     * @readonly
     * @deprecated
     */
    createdAt?: Date | null;
    /**
     * @internal
     * @internal
     * @readonly
     * @deprecated
     */
    updatedAt?: Date | null;
    /**
     * ID of the phase that currently holds the card.
     * @format GUID
     * @readonly
     */
    phaseId?: string | null;
    /**
     * Date and time the card was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date and time the card was updated.
     * @readonly
     */
    _updatedDate?: Date | null;
}
export interface Attachment {
    /**
     * Attachment ID. For internal use.
     * @format GUID
     * @readonly
     */
    attachmentId?: string;
    /**
     * @internal
     * @internal
     * @deprecated
     */
    value?: string;
    /**
     * @internal
     * @internal
     * @deprecated
     */
    attachmentType?: AttachmentTypeWithLiterals;
    /**
     * ID of the contact attached to the card.
     * @format GUID
     */
    contactId?: string;
}
/** describes the supported types of attachments (currently only supports Contact which is the default type) */
export declare enum AttachmentType {
    ContactType = "ContactType"
}
/** @enumType */
export type AttachmentTypeWithLiterals = AttachmentType | 'ContactType';
export interface QueryPhasesRequest {
    /** Query, sort, and paging options. */
    query?: Query;
}
export interface Query {
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * Example of operators: `$eq`, `$ne`, `$lt`, `$lte`, `$gt`, `$gte`, `$in`, `$hasSome`, `$hasAll`, `$startsWith`, `$contains`
     */
    filter?: any;
    /**
     * Sort object in the following format:
     * `[{"fieldName":"sortField1","order":"ASC"},{"fieldName":"sortField2","order":"DESC"}]`
     */
    sort?: Sorting[];
    /** Paging options to limit and skip the number of items. */
    paging?: Paging;
    /** Array of projected fields. A list of specific field names to return. If `fieldsets` are also specified, the union of `fieldsets` and `fields` is returned. */
    fields?: string[];
    /** Array of named, predefined sets of projected fields. A array of predefined named sets of fields to be returned. Specifying multiple `fieldsets` will return the union of fields from all sets. If `fields` are also specified, the union of `fieldsets` and `fields` is returned. */
    fieldsets?: string[];
}
export interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
export declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
export type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
export interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
export interface QueryPhasesResponse {
    /** List of phases that matched the query criteria. */
    phases?: Phase[];
    /** Metadata for the page of results. */
    pagination?: PaginationResponse;
}
export interface PaginationResponse {
    /** Number of items that were skipped in the current sort order. */
    offset?: number;
    /** Total number of items that matched the filter. */
    total?: number;
    /** Number of returned items. */
    count?: number;
}
export interface ListPhasesRequest {
    /**
     * ID of the workflow whose phases will be listed.
     * @format GUID
     */
    workflowId: string;
    /** Number of items to return. */
    limit?: number | null;
    /**
     * Number of items to skip in the current sort order.
     *
     * Defaults to `0`.
     */
    offset?: number | null;
    /**
     * Supported fields:
     * `id`, `name`
     *
     * List of fields to sort by.
     * Formatted as `field:direction`,
     * where field is the field name
     * and direction is `asc` (ascending) or `desc` (descending).
     *
     * Sorting is applied lexicographically, so `"abc"` comes after `"XYZ"`.
     */
    sort?: string[];
}
export interface ListPhasesResponse {
    /** List of phases. */
    phases?: Phase[];
    /** Metadata for the page of results. */
    pagination?: PaginationResponse;
}
export interface GetPhaseRequest {
    /**
     * ID of the phase to retrieve.
     * @format GUID
     */
    _id: string;
}
export interface GetPhaseResponse {
    /** Requested phase. */
    phase?: Phase;
}
export interface UpdatePhaseRequest {
    /**
     * ID of the phase to update.
     * @format GUID
     */
    _id: string;
    /** Phase details to update. */
    phase?: PhaseInfo;
}
export interface UpdatePhaseResponse {
}
export interface CreatePhaseRequest {
    /**
     * ID of the workflow to create the phase in.
     * @format GUID
     */
    workflowId: string;
    /** Phase details. */
    phase?: PhaseInfo;
    /**
     * Phase position, where the first phase is `0`.
     *
     * If a phase already occupies the specified position,
     * that phase and any subsequent phases
     * are shifted to the right by 1.
     *
     * Defaults to the last position,
     * which is displayed before the win phase.
     */
    position?: number | null;
}
export interface CreatePhaseResponse {
    /**
     * ID of the newly created phase.
     * @format GUID
     */
    _id?: string | null;
}
export interface DeletePhaseRequest {
    /**
     * ID of the phase to delete.
     * @format GUID
     */
    _id: string;
}
export interface DeletePhaseResponse {
}
export interface MovePhaseRequest {
    /**
     * ID of the workflow that contains the phase to move.
     * @format GUID
     */
    workflowId: string;
    /**
     * ID of the phase to move.
     * @format GUID
     */
    _id: string;
    /**
     * New phase position, where the first phase is `0`.
     *
     * If a phase already occupies the specified position,
     * that phase and any subsequent phases
     * are shifted to the right by 1.
     */
    newPosition: number | null;
}
export interface MovePhaseResponse {
}
type PhaseNonNullablePaths = `cardsList.total` | `cardsList.cards` | `cardsList.cards.${number}.info.primaryAttachment.attachmentId` | `cardsList.cards.${number}.info.primaryAttachment.value` | `cardsList.cards.${number}.info.primaryAttachment.attachmentType` | `cardsList.cards.${number}.info.primaryAttachment.contactId`;
/**
 * Retrieves a list of a workflow's phases.
 *
 *
 * The `listPhases()` function returns a Promise that resolves to a list containing information about the specified workflow's phases.
 *
 *
 * Use the `options` parameter to specify which phases to retrieve and in which order to retrieve them. Phases can be sorted based on their `"id"`, `"name"`, and `"position"`. If no `limit` parameter is passed, the first 50 cards are returned. Sort order defaults to by `"position"` ascending.
 *
 *
 * This function requires you to specify the ID of a workflow. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param workflowId - ID of the workflow whose phases will be listed.
 * @public
 * @documentationMaturity preview
 * @requiredField workflowId
 * @param options - Options to use when retrieving the list of workflow phases.
 * @permissionId workflows.view
 * @fqn com.wixpress.workflow.api.v1.PhasesService.ListPhases
 */
export declare function listPhases(workflowId: string, options?: ListPhasesOptions): Promise<NonNullablePaths<ListPhasesResponse, {
    [P in PhaseNonNullablePaths]: `phases.${number}.${P}`;
}[PhaseNonNullablePaths] | `pagination.offset` | `pagination.total` | `pagination.count`>>;
export interface ListPhasesOptions {
    /** Number of items to return. */
    limit?: number | null;
    /**
     * Number of items to skip in the current sort order.
     *
     * Defaults to `0`.
     */
    offset?: number | null;
    /**
     * Supported fields:
     * `id`, `name`
     *
     * List of fields to sort by.
     * Formatted as `field:direction`,
     * where field is the field name
     * and direction is `asc` (ascending) or `desc` (descending).
     *
     * Sorting is applied lexicographically, so `"abc"` comes after `"XYZ"`.
     */
    sort?: string[];
}
/**
 * Retrieves a phase by ID.
 *
 *
 * The `getPhase()` function returns a Promise that resolves to the phase with the specified ID.
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param _id - ID of the phase to retrieve.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @permissionId workflows.view
 * @returns Requested phase.
 * @fqn com.wixpress.workflow.api.v1.PhasesService.GetPhase
 */
export declare function getPhase(_id: string): Promise<NonNullablePaths<Phase, PhaseNonNullablePaths>>;
/**
 * Updates an existing workflow phase.
 *
 *
 * The `updatePhase()` function returns a Promise that resolves when the phase has been updated with the specified values.
 *
 *
 * Only the properties passed in the `phase` object will be updated. All other properties will remain the same.
 *
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param _id - ID of the phase to update.
 * @param phase - Phase details to update.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField phase
 * @param options - Phase information to update.
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.PhasesService.UpdatePhase
 */
export declare function updatePhase(_id: string, phase: PhaseInfo): Promise<void>;
/**
 * Creates a new workflow phase.
 *
 *
 * The `createPhase()` function returns a Promise that resolves to the created phase ID when the phase is created in the specified workflow.
 *
 *
 * Pass a value for the `position` parameter to specify the newly created phase's position within the specified workflow. Positions are zero-based, meaning the first position is `0`.
 *
 *
 * When omitted, the newly created phase is added as the last non-win phase.
 *
 *
 * This function requires you to specify the ID of a workflow. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param workflowId - ID of the workflow to create the phase in.
 * @param phase - Phase details.
 * @public
 * @documentationMaturity preview
 * @requiredField phase
 * @requiredField phase.name
 * @requiredField workflowId
 * @param options - Options to use when creating workflow phases.
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.PhasesService.CreatePhase
 */
export declare function createPhase(workflowId: string, phase: NonNullablePaths<PhaseInfo, `name`>, options?: CreatePhaseOptions): Promise<CreatePhaseResponse>;
export interface CreatePhaseOptions {
    /**
     * Phase position, where the first phase is `0`.
     *
     * If a phase already occupies the specified position,
     * that phase and any subsequent phases
     * are shifted to the right by 1.
     *
     * Defaults to the last position,
     * which is displayed before the win phase.
     */
    position?: number | null;
}
/**
 * Deletes a workflow phase.
 *
 *
 * The `deletePhase()` function returns a Promise when the specified phase has been deleted.
 *
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param _id - ID of the phase to delete.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.PhasesService.DeletePhase
 */
export declare function deletePhase(_id: string): Promise<void>;
/**
 * Moves a phase to a new position with a workflow.
 *
 *
 * The `movePhase()` function returns a Promise when the specified phase has been moved to the new position.
 *
 *
 * Use the `newPosition` parameter to specify the new phase position within the workflow. Any non-win phase can be moved to any non-win position. The win phase cannot be moved. Positions are zero-based, meaning the first position is `0`.
 *
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param newPosition - New phase position, where the first phase is `0`.
 *
 * If a phase already occupies the specified position,
 * that phase and any subsequent phases
 * are shifted to the right by 1.
 * @public
 * @documentationMaturity preview
 * @requiredField identifiers
 * @requiredField identifiers._id
 * @requiredField identifiers.workflowId
 * @requiredField newPosition
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.PhasesService.MovePhase
 */
export declare function movePhase(identifiers: NonNullablePaths<MovePhaseIdentifiers, `_id` | `workflowId`>, newPosition: number): Promise<void>;
export interface MovePhaseIdentifiers {
    /**
     * ID of the workflow that contains the phase to move.
     * @format GUID
     */
    workflowId: string;
    /**
     * ID of the phase to move.
     * @format GUID
     */
    _id: string;
}
export {};
